@@ -1,5 +1,6 @@
 from django.conf.urls import patterns, url, include
 from django.contrib.auth import views as auth_views
+from django.core.urlresolvers import reverse_lazy
 
 from oscar.core.application import Application
 from oscar.apps.catalogue.app import application as catalogue_app
@@ -12,6 +13,7 @@ from oscar.apps.offer.app import application as offer_app
 from oscar.apps.dashboard.app import application as dashboard_app
 
 from oscar.apps.customer import forms
+from oscar.views.decorators import login_forbidden
 
 
 class Shop(Application):
@@ -28,6 +30,7 @@ class Shop(Application):
 
     def get_urls(self):
         urlpatterns = patterns('',
+            (r'^i18n/', include('django.conf.urls.i18n')),
             (r'^catalogue/', include(self.catalogue_app.urls)),
             (r'^basket/', include(self.basket_app.urls)),
             (r'^checkout/', include(self.checkout_app.urls)),
@@ -39,16 +42,20 @@ class Shop(Application):
             # Password reset - as we're using Django's default view funtions,
             # we can't namespace these urls as that prevents
             # the reverse function from working.
-            url(r'^password-reset/$', auth_views.password_reset,
-                {'password_reset_form': forms.PasswordResetForm},
+            url(r'^password-reset/$',
+                login_forbidden(auth_views.password_reset),
+                {'password_reset_form': forms.PasswordResetForm,
+                 'post_reset_redirect': reverse_lazy('password-reset-done')},
                 name='password-reset'),
-            url(r'^password-reset/done/$', auth_views.password_reset_done,
+            url(r'^password-reset/done/$',
+                login_forbidden(auth_views.password_reset_done),
                 name='password-reset-done'),
             url(r'^password-reset/confirm/(?P<uidb36>[0-9A-Za-z]{1,13})-(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/$',
-                auth_views.password_reset_confirm,
+                login_forbidden(auth_views.password_reset_confirm),
+                {'post_reset_redirect': reverse_lazy('password-reset-complete')},
                 name='password-reset-confirm'),
             url(r'^password-reset/complete/$',
-                auth_views.password_reset_complete,
+                login_forbidden(auth_views.password_reset_complete),
                 name='password-reset-complete'),
             (r'', include(self.promotions_app.urls)),
         )
