@@ -1,24 +1,85 @@
 from urlparse import urlparse
+
 from django.contrib import messages
+from django.template.loader import render_to_string
+from django.template import RequestContext
 from django.core.urlresolvers import reverse, resolve
+from django.utils import simplejson as json
 from django.db.models import get_model
-from django.http import HttpResponseRedirect, Http404
+from django.http import HttpResponseRedirect, Http404, HttpResponse
 from django.views.generic import FormView, View
 from django.utils.translation import ugettext_lazy as _
 from django.core.exceptions import ObjectDoesNotExist
 
 from extra_views import ModelFormSetView
+from oscar.core import ajax
 from oscar.apps.basket.signals import basket_addition, voucher_addition
+from oscar.templatetags.currency_filters import currency
 from oscar.core.loading import get_class, get_classes
 Applicator = get_class('offer.utils', 'Applicator')
-BasketLineForm, AddToBasketForm, BasketVoucherForm, \
-        SavedLineFormSet, SavedLineForm, ProductSelectionForm = get_classes(
-            'basket.forms', ('BasketLineForm', 'AddToBasketForm',
-                             'BasketVoucherForm', 'SavedLineFormSet',
-                             'SavedLineForm', 'ProductSelectionForm'))
+(BasketLineForm, AddToBasketForm, BasketVoucherForm,
+ SavedLineFormSet, SavedLineForm, ProductSelectionForm) = get_classes(
+     'basket.forms', ('BasketLineForm', 'AddToBasketForm',
+                      'BasketVoucherForm', 'SavedLineFormSet',
+                      'SavedLineForm', 'ProductSelectionForm'))
 Repository = get_class('shipping.repository', ('Repository'))
 
 
+def get_messages(basket, offers_before, offers_after,
+                 include_buttons=True):
+    """
+    Return the messages about offer changes
+    """
+    # Look for changes in offers
+    offers_lost = set(offers_before.keys()).difference(
+        set(offers_after.keys()))
+    offers_gained = set(offers_after.keys()).difference(
+        set(offers_before.keys()))
+
+    # Build a list of (level, msg) tuples
+    offer_messages = []
+    for offer_id in offers_lost:
+        offer = offers_before[offer_id]
+        msg = render_to_string(
+            'basket/messages/offer_lost.html',
+            {'offer': offer})
+        offer_messages.append((
+            messages.WARNING, msg))
+    for offer_id in offers_gained:
+        offer = offers_after[offer_id]
+        msg = render_to_string(
+            'basket/messages/offer_gained.html',
+            {'offer': offer})
+        offer_messages.append((
+            messages.SUCCESS, msg))
+
+    # We use the 'include_buttons' parameter to determine whether to show the
+    # 'Checkout now' buttons.  We don't want to show these on the basket page.
+    msg = render_to_string(
+        'basket/messages/new_total.html',
+        {'basket': basket,
+         'include_buttons': include_buttons})
+    offer_messages.append((
+        messages.INFO, msg))
+
+    return offer_messages
+
+
+def apply_messages(request, offers_before):
+    """
+    Set flash messages triggered by changes to the basket
+    """
+    # Re-apply offers to see if any new ones are now available
+    request.basket.reset_offer_applications()
+    Applicator().apply(request, request.basket)
+    offers_after = request.basket.applied_offers()
+
+    for level, msg in get_messages(
+            request.basket, offers_before, offers_after):
+        messages.add_message(
+            request, level, msg, extra_tags='safe noicon')
+
+
 class BasketView(ModelFormSetView):
     model = get_model('basket', 'Line')
     basket_model = get_model('basket', 'Basket')
@@ -30,6 +91,10 @@ class BasketView(ModelFormSetView):
     def get_queryset(self):
         return self.request.basket.all_lines()
 
+    def get_shipping_methods(self, basket):
+        return Repository().get_shipping_methods(
+            self.request.user, self.request.basket)
+
     def get_default_shipping_method(self, basket):
         return Repository().get_default_shipping_method(
             self.request.user, self.request.basket)
@@ -52,17 +117,23 @@ class BasketView(ModelFormSetView):
             if offer.is_condition_partially_satisfied(basket):
                 data = {
                     'message': offer.get_upsell_message(basket),
-                    'offer': offer
-                }
+                    'offer': offer}
                 msgs.append(data)
         return msgs
 
     def get_context_data(self, **kwargs):
         context = super(BasketView, self).get_context_data(**kwargs)
         context['voucher_form'] = BasketVoucherForm()
+
+        # Shipping information is included to give an idea of the total order
+        # cost.  It is also important for PayPal Express where the customer
+        # gets redirected away from the basket page and needs to see what the
+        # estimated order total is beforehand.
         method = self.get_default_shipping_method(self.request.basket)
         context['shipping_method'] = method
-        context['shipping_charge_incl_tax'] = method.basket_charge_incl_tax()
+        context['shipping_methods'] = self.get_shipping_methods(
+            self.request.basket)
+
         context['order_total_incl_tax'] = (
             self.request.basket.total_incl_tax +
             method.basket_charge_incl_tax())
@@ -89,32 +160,86 @@ class BasketView(ModelFormSetView):
         return context
 
     def get_success_url(self):
-        messages.success(self.request, _("Basket updated"))
         return self.request.META.get('HTTP_REFERER', reverse('basket:summary'))
 
     def formset_valid(self, formset):
+        # Store offers before any changes are made so we can inform the user of
+        # any changes
+        offers_before = self.request.basket.applied_offers()
         save_for_later = False
+
+        # Keep a list of messages - we don't immediately call
+        # django.contrib.messages as we may be returning an AJAX response in
+        # which case we pass the messages back in a JSON payload.
+        flash_messages = ajax.FlashMessages()
+
         for form in formset:
             if (hasattr(form, 'cleaned_data') and
-                form.cleaned_data['save_for_later']):
+                    form.cleaned_data['save_for_later']):
                 line = form.instance
                 if self.request.user.is_authenticated():
                     self.move_line_to_saved_basket(line)
-                    messages.info(
-                        self.request,
-                        _(u"'%(title)s' has been saved for later") % {
-                            'title': line.product})
+
+                    msg = render_to_string(
+                        'basket/messages/line_saved.html',
+                        {'line': line})
+                    flash_messages.info(msg)
+
                     save_for_later = True
                 else:
-                    messages.error(
-                        self.request,
-                        _("You can't save an item for later if you're not logged in!"))
+                    msg = _("You can't save an item for later if you're "
+                            "not logged in!")
+                    messages.error(self.request, msg)
                     return HttpResponseRedirect(self.get_success_url())
 
         if save_for_later:
             # No need to call super if we're moving lines to the saved basket
-            return HttpResponseRedirect(self.get_success_url())
-        return super(BasketView, self).formset_valid(formset)
+            response = HttpResponseRedirect(self.get_success_url())
+        else:
+            # Save changes to basket as per normal
+            response = super(BasketView, self).formset_valid(formset)
+
+        # If AJAX submission, don't redirect but reload the basket content HTML
+        if self.request.is_ajax():
+            # Reload basket and apply offers again
+            self.request.basket = get_model('basket', 'Basket').objects.get(
+                id=self.request.basket.id)
+            Applicator().apply(self.request, self.request.basket)
+            offers_after = self.request.basket.applied_offers()
+
+            for level, msg in get_messages(
+                    self.request.basket, offers_before,
+                    offers_after, include_buttons=False):
+                flash_messages.add_message(level, msg)
+
+            # Reload formset - we have to remove the POST fields from the
+            # kwargs as, if they are left in, the formset won't construct
+            # correctly as there will be a state mismatch between the
+            # management form and the database.
+            kwargs = self.get_formset_kwargs()
+            del kwargs['data']
+            del kwargs['files']
+            if 'queryset' in kwargs:
+                del kwargs['queryset']
+            formset = self.get_formset()(queryset=self.get_queryset(),
+                                         **kwargs)
+            ctx = self.get_context_data(formset=formset,
+                                        basket=self.request.basket)
+            return self.json_response(ctx, flash_messages)
+
+        apply_messages(self.request, offers_before)
+
+        return response
+
+    def json_response(self, ctx, flash_messages):
+        basket_html = render_to_string(
+            'basket/partials/basket_content.html',
+            RequestContext(self.request, ctx))
+        payload = {
+            'content_html': basket_html,
+            'messages': flash_messages.to_json()}
+        return HttpResponse(json.dumps(payload),
+                            mimetype="application/json")
 
     def move_line_to_saved_basket(self, line):
         saved_basket, _ = get_model('basket', 'basket').saved.get_or_create(
@@ -122,13 +247,15 @@ class BasketView(ModelFormSetView):
         saved_basket.merge_line(line)
 
     def formset_invalid(self, formset):
-        errors = []
-        for error_dict in formset.errors:
-            errors += [error_list.as_text()
-                       for error_list in error_dict.values()]
-        msg = _("Your basket couldn't be updated because:\n%s") % (
-            "\n".join(errors),)
-        messages.warning(self.request, msg)
+        flash_messages = ajax.FlashMessages()
+        flash_messages.warning(_("Your basket couldn't be updated"))
+
+        if self.request.is_ajax():
+            ctx = self.get_context_data(formset=formset,
+                                        basket=self.request.basket)
+            return self.json_response(ctx, flash_messages)
+
+        flash_messages.apply_to_request(self.request)
         return super(BasketView, self).formset_invalid(formset)
 
 
@@ -174,10 +301,16 @@ class BasketAddView(FormView):
         return url
 
     def form_valid(self, form):
+        offers_before = self.request.basket.applied_offers()
         self.request.basket.add_product(
             form.instance, form.cleaned_data['quantity'],
             form.cleaned_options())
-        messages.success(self.request, self.get_success_message(form))
+
+        messages.success(self.request, self.get_success_message(form),
+                         extra_tags='safe noicon')
+
+        # Check for additional offer messages
+        apply_messages(self.request, offers_before)
 
         # Send signal for basket addition
         self.add_signal.send(
@@ -186,15 +319,10 @@ class BasketAddView(FormView):
         return super(BasketAddView, self).form_valid(form)
 
     def get_success_message(self, form):
-        qty = form.cleaned_data['quantity']
-        title = form.instance.get_title()
-        if qty == 1:
-            return _("'%(title)s' has been added to your basket") % {
-                'title': title}
-        else:
-            return _(
-                "'%(title)s' (quantity %(quantity)d) has been added to your"
-                "basket") % {'title': title, 'quantity': qty}
+        return render_to_string(
+            'basket/messages/addition.html',
+            {'product': form.instance,
+             'quantity': form.cleaned_data['quantity']})
 
     def form_invalid(self, form):
         msgs = []
@@ -234,9 +362,8 @@ class VoucherAddView(FormView):
                              voucher=voucher)
 
         # Recalculate discounts to see if the voucher gives any
-        self.request.basket.remove_discounts()
         Applicator().apply(self.request, self.request.basket)
-        discounts_after = self.request.basket.get_discounts()
+        discounts_after = self.request.basket.offer_applications
 
         # Look for discounts from this new voucher
         found_discount = False
@@ -339,19 +466,27 @@ class SavedView(ModelFormSetView):
         return kwargs
 
     def formset_valid(self, formset):
+        offers_before = self.request.basket.applied_offers()
+
         is_move = False
         for form in formset:
             if form.cleaned_data['move_to_basket']:
                 is_move = True
-                msg = _("'%(product)s' has been moved back to your basket") % {
-                    'product': form.instance.product}
-                messages.info(self.request, msg)
+                msg = render_to_string(
+                    'basket/messages/line_restored.html',
+                    {'line': form.instance})
+                messages.info(self.request, msg, extra_tags='safe noicon')
                 real_basket = self.request.basket
                 real_basket.merge_line(form.instance)
-        if is_move:
-            return HttpResponseRedirect(self.get_success_url())
 
-        return super(SavedView, self).formset_valid(formset)
+        if is_move:
+            # As we're changing the basket, we need to check if it qualifies
+            # for any new offers.
+            apply_messages(self.request, offers_before)
+            response = HttpResponseRedirect(self.get_success_url())
+        else:
+            response = super(SavedView, self).formset_valid(formset)
+        return response
 
     def formset_invalid(self, formset):
         messages.error(
