@@ -18,7 +18,9 @@ from django.conf import settings
 from django.db.models import get_model
 
 from oscar.views.generic import PostActionMixin
+from oscar.apps.customer.utils import get_password_reset_url
 from oscar.core.loading import get_class, get_profile_class, get_classes
+
 Dispatcher = get_class('customer.utils', 'Dispatcher')
 EmailAuthenticationForm, EmailUserCreationForm, SearchByDateRangeForm = get_classes(
     'customer.forms', ['EmailAuthenticationForm', 'EmailUserCreationForm',
@@ -53,6 +55,7 @@ class LogoutView(RedirectView):
 class ProfileUpdateView(FormView):
     form_class = ProfileForm
     template_name = 'customer/profile_form.html'
+    communication_type_code = 'EMAIL_CHANGED'
 
     def get_form_kwargs(self):
         kwargs = super(ProfileUpdateView, self).get_form_kwargs()
@@ -60,7 +63,32 @@ class ProfileUpdateView(FormView):
         return kwargs
 
     def form_valid(self, form):
+        # Grab current user instance before we save form.  We may need this to
+        # send a warning email if the email address is changed.
+        try:
+            old_user = User.objects.get(id=self.request.user.id)
+        except User.DoesNotExist:
+            old_user = None
+
         form.save()
+
+        # We have to look up the email address from the form's
+        # cleaned data because the object created by form.save() can
+        # either be a user or profile depending on AUTH_PROFILE_MODULE
+        new_email = form.cleaned_data['email']
+        if old_user and new_email != old_user.email:
+            # Email address has changed - send a confirmation email to the old
+            # address including a password reset link in case this is a
+            # suspicious change.
+            ctx = {
+                'site': get_current_site(self.request),
+                'reset_url': get_password_reset_url(old_user),
+                'new_email': new_email,
+            }
+            msgs = CommunicationEventType.objects.get_and_render(
+                code=self.communication_type_code, context=ctx)
+            Dispatcher().dispatch_user_messages(old_user, msgs)
+
         messages.success(self.request, "Profile updated")
         return HttpResponseRedirect(self.get_success_url())
 
@@ -366,59 +394,58 @@ class OrderDetailView(DetailView, PostActionMixin):
 
         This puts the contents of the previous order into your basket
         """
+
+        # Collect lines to be added to the basket and any warnings for lines
+        # that are no longer available.
         basket = self.request.basket
-
-        # Convert line attributes into basket options
-        lines_added = []
+        lines_to_add = []
         warnings = []
-        # Collect lines to be added to the basket and the warnings
         for line in order.lines.all():
-            if not line.product:
-                warnings.append(_("'%s' unavailable for re-order") % line.title)
-                continue
-
-            try:
-                basket_line = basket.lines.get(product=line.product)
-            except Line.DoesNotExist:
-                desired_qty = line.quantity
+            is_available, reason = line.is_available_to_reorder(basket,
+                self.request.user)
+            if is_available:
+                lines_to_add.append(line)
             else:
-                desired_qty = basket_line.quantity + line.quantity
-
-            is_available, reason = line.product.is_purchase_permitted(
-                                                        user=self.request.user,
-                                                        quantity=desired_qty)
-            if not is_available:
                 warnings.append(reason)
-                continue
-
-            lines_added.append(line)
-
-        # Check whether the number of items in the basket won't exceed the maximum
-        total_quantity = sum([line.quantity for line in lines_added])
-        is_quantity_allowed, reason = basket.is_quantity_allowed(total_quantity)
-
-        self.response = HttpResponseRedirect(reverse('customer:order-list'))
 
+        # Check whether the number of items in the basket won't exceed the
+        # maximum.
+        total_quantity = sum([line.quantity for line in lines_to_add])
+        is_quantity_allowed, reason = basket.is_quantity_allowed(
+            total_quantity)
         if not is_quantity_allowed:
             messages.warning(self.request, reason)
+            self.response = HttpResponseRedirect(
+                reverse('customer:order-list'))
             return
-        else:
-            # Add items to the basket, display warnings
-            for warning in warnings:
-                messages.warning(self.request, warning)
 
-            for line in lines_added:
-                options = []
-                for attribute in line.attributes.all():
-                    if attribute.option:
-                        options.append({'option': attribute.option, 'value': attribute.value})
-                basket.add_product(line.product, line.quantity, options)
+        # Add any warnings
+        for warning in warnings:
+            messages.warning(self.request, warning)
 
-        if len(lines_added) > 0:
+        for line in lines_to_add:
+            options = []
+            for attribute in line.attributes.all():
+                if attribute.option:
+                    options.append({
+                        'option': attribute.option,
+                        'value': attribute.value})
+            basket.add_product(line.product, line.quantity, options)
+
+        if len(lines_to_add) > 0:
             self.response = HttpResponseRedirect(reverse('basket:summary'))
-            messages.info(self.request,
-                          _("All available lines from order %s "
-                            "have been added to your basket") % order.number)
+            messages.info(
+                self.request,
+                _("All available lines from order %(number)s "
+                  "have been added to your basket") % {'number': order.number})
+        else:
+            self.response = HttpResponseRedirect(
+                reverse('customer:order-list'))
+            messages.warning(
+                self.request,
+                _("It is not possible to re-order order %(number)s "
+                  "as none of its lines are available to purchase") %
+                {'number': order.number})
 
 
 class OrderLineView(DetailView, PostActionMixin):
@@ -435,28 +462,10 @@ class OrderLineView(DetailView, PostActionMixin):
                                     args=(int(self.kwargs['order_number']),)))
         basket = self.request.basket
 
-        # Check whether basket items quantity won't exceed the maximum
-        is_quantity_allowed, reason = basket.is_quantity_allowed(line.quantity)
-        if not is_quantity_allowed:
-            messages.warning(self.request, reason)
-            return
+        line_available_to_reorder, reason = line.is_available_to_reorder(basket,
+            self.request.user)
 
-        if not line.product:
-            messages.info(self.request, _("This product is no longer available for re-order"))
-            return
-
-        try:
-            basket_line = basket.lines.get(product=line.product)
-        except Line.DoesNotExist:
-            desired_qty = line.quantity
-        else:
-            desired_qty = basket_line.quantity + line.quantity
-
-        is_available, reason = line.product.is_purchase_permitted(
-                                                    user=self.request.user,
-                                                    quantity=desired_qty)
-
-        if not is_available:
+        if not line_available_to_reorder:
             messages.warning(self.request, reason)
             return
 
@@ -557,6 +566,7 @@ class AnonymousOrderDetailView(DetailView):
 class ChangePasswordView(FormView):
     form_class = PasswordChangeForm
     template_name = 'customer/change_password_form.html'
+    communication_type_code = 'PASSWORD_CHANGED'
 
     def get_form_kwargs(self):
         kwargs = super(ChangePasswordView, self).get_form_kwargs()
@@ -566,6 +576,15 @@ class ChangePasswordView(FormView):
     def form_valid(self, form):
         form.save()
         messages.success(self.request, _("Password updated"))
+
+        ctx = {
+            'site': get_current_site(self.request),
+            'reset_url': get_password_reset_url(self.request.user),
+        }
+        msgs = CommunicationEventType.objects.get_and_render(
+            code=self.communication_type_code, context=ctx)
+        Dispatcher().dispatch_user_messages(self.request.user, msgs)
+
         return HttpResponseRedirect(self.get_success_url())
 
     def get_success_url(self):
