@@ -1,16 +1,8 @@
 from django.conf.urls import patterns, url
-from django.contrib.admin.views.decorators import staff_member_required
-from django.utils.translation import ugettext_lazy as _
 
+from oscar.views.decorators import staff_member_required
 from oscar.core.application import Application
 from oscar.apps.dashboard.catalogue import views
-from oscar.apps.dashboard.nav import register, Node
-
-node = Node(_('Catalogue'))
-node.add_child(Node(_('Products'), 'dashboard:catalogue-product-list'))
-node.add_child(Node(_('Categories'), 'dashboard:catalogue-category-list'))
-node.add_child(Node(_('Stock alerts'), 'dashboard:stock-alert-list'))
-register(node, 10)
 
 
 class CatalogueApplication(Application):
@@ -18,9 +10,9 @@ class CatalogueApplication(Application):
 
     product_list_view = views.ProductListView
     product_create_redirect_view = views.ProductCreateRedirectView
-    product_create_view = views.ProductCreateView
-    product_update_view = views.ProductUpdateView
-    
+    product_createupdate_view = views.ProductCreateUpdateView
+    product_delete_view = views.ProductDeleteView
+
     category_list_view = views.CategoryListView
     category_detail_list_view = views.CategoryDetailListView
     category_create_view = views.CategoryCreateView
@@ -31,25 +23,33 @@ class CatalogueApplication(Application):
 
     def get_urls(self):
         urlpatterns = patterns('',
-            url(r'^products/(?P<pk>\d+)/$', self.product_update_view.as_view(),
+            url(r'^products/(?P<pk>\d+)/$', self.product_createupdate_view.as_view(),
                 name='catalogue-product'),
-            url(r'^products/create/$', self.product_create_redirect_view.as_view(),
+            url(r'^products/create/$',
+                self.product_create_redirect_view.as_view(),
                 name='catalogue-product-create'),
-            url(r'^products/create/(?P<product_class_id>\d+)/$', self.product_create_view.as_view(),
+            url(r'^products/create/(?P<product_class_id>\d+)/$',
+                self.product_createupdate_view.as_view(),
                 name='catalogue-product-create'),
+            url(r'^products/(?P<pk>\d+)/delete/$',
+                self.product_delete_view.as_view(),
+                name='catalogue-product-delete'),
             url(r'^$', self.product_list_view.as_view(),
                 name='catalogue-product-list'),
             url(r'^stock-alerts/$', self.stock_alert_view.as_view(),
                 name='stock-alert-list'),
             url(r'^categories/$', self.category_list_view.as_view(),
                 name='catalogue-category-list'),
-            url(r'^categories/(?P<pk>\d+)/$', self.category_detail_list_view.as_view(),
+            url(r'^categories/(?P<pk>\d+)/$',
+                self.category_detail_list_view.as_view(),
                 name='catalogue-category-detail-list'),
             url(r'^categories/create/$', self.category_create_view.as_view(),
                 name='catalogue-category-create'),
-            url(r'^categories/update/(?P<pk>\d+)/$', self.category_update_view.as_view(),
+            url(r'^categories/(?P<pk>\d+)/update/$',
+                self.category_update_view.as_view(),
                 name='catalogue-category-update'),
-            url(r'^categories/delete/(?P<pk>\d+)/$', self.category_delete_view.as_view(),
+            url(r'^categories/(?P<pk>\d+)/delete/$',
+                self.category_delete_view.as_view(),
                 name='catalogue-category-delete'),
         )
         return self.post_process_urls(urlpatterns)
