@@ -1,4 +1,3 @@
-import csv
 import datetime
 from decimal import Decimal as D, InvalidOperation
 
@@ -13,10 +12,12 @@ from django.shortcuts import get_object_or_404
 from django.template.defaultfilters import date as format_date
 from django.utils.datastructures import SortedDict
 from django.views.generic import ListView, DetailView, UpdateView, FormView
+from django.conf import settings
 
 from oscar.core.loading import get_class
 from oscar.apps.dashboard.orders import forms
 from oscar.views.generic import BulkEditMixin
+from oscar.apps.dashboard.reports.csv_utils import CsvUnicodeWriter
 from oscar.apps.payment.exceptions import PaymentError
 from oscar.apps.order.exceptions import InvalidShippingEvent, InvalidStatus
 
@@ -58,8 +59,10 @@ class OrderStatsView(FormView):
         stats = {
             'total_orders': orders.count(),
             'total_lines': Line.objects.filter(order__in=orders).count(),
-            'total_revenue': orders.aggregate(Sum('total_incl_tax'))['total_incl_tax__sum'] or D('0.00'),
-            'order_status_breakdown': orders.order_by('status').values('status').annotate(freq=Count('id'))
+            'total_revenue': orders.aggregate(
+                Sum('total_incl_tax'))['total_incl_tax__sum'] or D('0.00'),
+            'order_status_breakdown': orders.order_by('status').values(
+                'status').annotate(freq=Count('id'))
         }
         return stats
 
@@ -78,7 +81,7 @@ class OrderListView(ListView, BulkEditMixin):
     current_view = 'dashboard:order-list'
 
     def get(self, request, *args, **kwargs):
-        if 'order_number' in request.GET and request.GET.get('response_format', None) == 'html':
+        if 'order_number' in request.GET and request.GET.get('response_format', 'html') == 'html':
             try:
                 order = Order.objects.get(number=request.GET['order_number'])
             except Order.DoesNotExist:
@@ -136,12 +139,22 @@ class OrderListView(ListView, BulkEditMixin):
         if data['name']:
             # If the value is two words, then assume they are first name and last name
             parts = data['name'].split()
-            if len(parts) == 2:
-                queryset = queryset.filter(Q(user__first_name__istartswith=parts[0]) |
-                                           Q(user__last_name__istartswith=parts[1])).distinct()
+            allow_anon = getattr(settings, 'OSCAR_ALLOW_ANON_CHECKOUT', False)
+
+            if len(parts) == 1:
+                parts = [data['name'], data['name']]
             else:
-                queryset = queryset.filter(Q(user__first_name__istartswith=data['name']) |
-                                           Q(user__last_name__istartswith=data['name'])).distinct()
+                parts = [parts[0], parts[1:]]
+
+            filter = Q(user__first_name__istartswith=parts[0]) |\
+                     Q(user__last_name__istartswith=parts[1])
+            if allow_anon:
+                filter |= Q(billing_address__first_name__istartswith=parts[0]) |\
+                          Q(shipping_address__first_name__istartswith=parts[0]) |\
+                          Q(billing_address__last_name__istartswith=parts[1]) |\
+                          Q(shipping_address__last_name__istartswith=parts[1])
+
+            queryset = queryset.filter(filter).distinct()
             desc_ctx['name_filter'] = _(" with customer name matching '%s'") % data['name']
 
         if data['product_title']:
@@ -221,7 +234,7 @@ class OrderListView(ListView, BulkEditMixin):
     def download_selected_orders(self, request, orders):
         response = HttpResponse(mimetype='text/csv')
         response['Content-Disposition'] = 'attachment; filename=%s' % self.get_download_filename(request)
-        writer = csv.writer(response, delimiter=',')
+        writer = CsvUnicodeWriter(response, delimiter=',')
 
         meta_data = (('number', _('Order number')),
                      ('value', _('Order value')),
@@ -313,7 +326,10 @@ class OrderDetailView(DetailView):
                 return self.reload_page_response()
             else:
                 line_ids = request.POST.getlist('selected_line')
-                line_quantities = [int(qty) for qty in request.POST.getlist('selected_line_qty')]
+                line_quantities = []
+                for line_id in line_ids:
+                    qty = request.POST.get('selected_line_qty_%s' % line_id)
+                    line_quantities.append(int(qty))
                 lines = order.lines.filter(id__in=line_ids)
                 if lines.count() == 0:
                     messages.error(self.request, _("You must select some lines to act on"))
