@@ -1,13 +1,8 @@
 from django.conf.urls import patterns, url
-from django.contrib.admin.views.decorators import staff_member_required
-from django.utils.translation import ugettext_lazy as _
 
+from oscar.views.decorators import staff_member_required
 from oscar.core.application import Application
 from oscar.apps.dashboard.vouchers import views
-from oscar.apps.dashboard.nav import register, Node
-
-node = Node(_('Vouchers'), 'dashboard:voucher-list')
-register(node, 60)
 
 
 class VoucherDashboardApplication(Application):
@@ -22,10 +17,14 @@ class VoucherDashboardApplication(Application):
     def get_urls(self):
         urlpatterns = patterns('',
             url(r'^$', self.list_view.as_view(), name='voucher-list'),
-            url(r'^create/$', self.create_view.as_view(), name='voucher-create'),
-            url(r'^update/(?P<pk>\d+)/$', self.update_view.as_view(), name='voucher-update'),
-            url(r'^delete/(?P<pk>\d+)/$', self.delete_view.as_view(), name='voucher-delete'),
-            url(r'^stats/(?P<pk>\d+)/$', self.stats_view.as_view(), name='voucher-stats'),
+            url(r'^create/$', self.create_view.as_view(),
+                name='voucher-create'),
+            url(r'^update/(?P<pk>\d+)/$', self.update_view.as_view(),
+                name='voucher-update'),
+            url(r'^delete/(?P<pk>\d+)/$', self.delete_view.as_view(),
+                name='voucher-delete'),
+            url(r'^stats/(?P<pk>\d+)/$', self.stats_view.as_view(),
+                name='voucher-stats'),
         )
         return self.post_process_urls(urlpatterns)
 
