@@ -23,8 +23,8 @@ class VoucherForm(forms.Form):
         queryset=Range.objects.all(),
     )
     type_choices = (
-        (Benefit.PERCENTAGE, _('% off products in range')),
-        (Benefit.FIXED, _('Fixed amount off products in range')),
+        (Benefit.PERCENTAGE, _('Percentage off of products in range')),
+        (Benefit.FIXED, _('Fixed amount off of products in range')),
     )
     benefit_type = forms.ChoiceField(
         choices=type_choices,
@@ -63,9 +63,9 @@ class VoucherForm(forms.Form):
 
     def clean(self):
         cleaned_data = super(VoucherForm, self).clean()
-        start_date = cleaned_data['start_date']
-        end_date = cleaned_data['end_date']
-        if end_date < start_date:
+        start_date = cleaned_data.get('start_date', None)
+        end_date = cleaned_data.get('end_date', None)
+        if start_date and end_date and end_date < start_date:
             raise forms.ValidationError(_("The start date must be before the end date"))
         return cleaned_data
 
