@@ -11,9 +11,4 @@ def get_promotion_classes():
             HandPickedProductList)
 
 
-PROMOTION_POSITIONS = (('page', 'Page'),
-                       ('right', 'Right-hand sidebar'),
-                       ('left', 'Left-hand sidebar'))
-
-
 PROMOTION_CLASSES = get_promotion_classes()
