@@ -1,4 +1,3 @@
-from django.http import HttpResponseRedirect
 from django.views.generic import TemplateView, RedirectView
 from django.core.urlresolvers import reverse
 
@@ -8,17 +7,16 @@ class HomeView(TemplateView):
 
 
 class RecordClickView(RedirectView):
-    
-    model=None
-    
+    permanent = False
+    model = None
+
     def get_redirect_url(self, **kwargs):
         try:
             prom = self.model.objects.get(pk=kwargs['pk'])
         except self.model.DoesNotExist:
-            return reverse('promotions:home')  
+            return reverse('promotions:home')
 
         if prom.promotion.has_link:
             prom.record_click()
             return prom.link_url
         return reverse('promotions:home')
-
