@@ -1,6 +1,10 @@
 from django.shortcuts import render
 
 
+def handler403(request):
+    return render(request, '403.html', status=403)
+
+
 def handler404(request):
     return render(request, '404.html', status=404)
 
